PictureModel class

Constructors

PictureModel({required String stringUrl, required double top, required bool isSelected, double angle = 0, required double scale, required bool isNetwork, required double left})

Properties

angle ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isNetwork ↔ bool
getter/setter pair
isSelected ↔ bool
getter/setter pair
left ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ double
Scale image
getter/setter pair
stringUrl ↔ String
getter/setter pair
top ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited