StickerEditingBox constructor
const
StickerEditingBox({
- Key? key,
- required double boundWidth,
- required double boundHeight,
- required PictureModel pictureModel,
- dynamic onTap()?,
- dynamic onCancel()?,
Create a StickerEditingBox widget
pictureModel detail of your picture
onTap callback function that called when you tap on StickerEditingBox
onCancel callback function that called when you tap on Cross icon in StickerEditingBox border
Implementation
const StickerEditingBox(
{Key? key,
required this.boundWidth,
required this.boundHeight,
required this.pictureModel,
this.onTap,
this.onCancel})
: super(key: key);