TextEditingBox class

Inheritance

Constructors

TextEditingBox({Key? key, required TextModel newText, required double boundWidth, required double boundHeight, required List<String> fonts, bool isSelected = false, dynamic onCancel()?, dynamic onTap()?, List<Color>? palletColor})
Create a TextEditingBox widget

Properties

boundHeight → double
Your widget should be move within this boundHeight
final
boundWidth → double
Your widget should be move within this boundWidth
final
fonts → List<String>
Total Fonts option that you want to give to user
final
hashCode → int
The hash code for this object.
no setterinherited
isSelected ↔ bool
For Visibility of editing border
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
newText → TextModel
final
onCancel → dynamic Function()?
If you use onCancel then you Have to manage IsSelected field in TextModel and isSelected
final
onTap → dynamic Function()?
If you use onTap then you Have to manage IsSelected field in TextModel and isSelected
final
palletColor ↔ List<Color>?
Total Colors option that you want to give to user
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TextEditingBoxState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited