TextEditingBox constructor
TextEditingBox({})
Create a TextEditingBox widget
TextModel detail of your picture
onTap callback function that called when you tap on TextEditingBox
onCancel callback function that called when you tap on Cross icon in TextEditingBox border
Implementation
TextEditingBox(
{Key? key,
required this.newText,
required this.boundWidth,
required this.boundHeight,
required this.fonts,
this.isSelected = false,
this.onCancel,
this.onTap,
this.palletColor})
: super(key: key);