TextModel class

Constructors

TextModel({required String name, required TextStyle textStyle, required double top, required bool isSelected, required TextAlign textAlign, required double scale, required double left})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSelected ↔ bool
getter/setter pair
left ↔ double
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ double
getter/setter pair
textAlign ↔ TextAlign
getter/setter pair
textStyle ↔ TextStyle
getter/setter pair
top ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited